@@ -1,14 +1,11 @@
 package Catalyst::Model::MongoDB;
-BEGIN {
-  $Catalyst::Model::MongoDB::AUTHORITY = 'cpan:GETTY';
-}
-{
-  $Catalyst::Model::MongoDB::VERSION = '0.12';
-}
+our $AUTHORITY = 'cpan:GETTY';
+$Catalyst::Model::MongoDB::VERSION = '0.13';
 # ABSTRACT: MongoDB model class for Catalyst
 use MongoDB;
 use MongoDB::OID;
 use Moose;
+use version;
 
 BEGIN { extends 'Catalyst::Model' }
 
@@ -40,7 +37,8 @@ sub _build_connection {
   # attempt authentication only if we have all three parameters for
   # MongoDB::Connection->authenticate()
   if ($self->dbname && $self->has_username && $self->has_password) {
-      $conn->authenticate($self->dbname, $self->username, $self->password);
+      $conn->authenticate($self->dbname, $self->username, $self->password)
+          if version->parse($MongoDB::VERSION) < 1.0;
   }
 
   return $conn;
@@ -157,7 +155,7 @@ Catalyst::Model::MongoDB - MongoDB model class for Catalyst
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -274,12 +272,12 @@ IRC
 
 Repository
 
-  http://github.com/Getty/p5-catalyst-model-mongodb
+  http://github.com/singingfish/p5-catalyst-model-mongodb
   Pull request and additional contributors are welcome
 
 Issue Tracker
 
-  http://github.com/Getty/p5-catalyst-model-mongodb/issues
+  http://github.com/singingfish/p5-catalyst-model-mongodb/issues
 
 =head1 AUTHOR
 
